@@ -16,7 +16,7 @@
 # Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 # MA 02110-1301 USA.
 #
-# $Id: Detector.pm,v 1.8 2007/07/12 23:40:58 evertonm Exp $
+# $Id: Detector.pm,v 1.9 2007/07/17 15:05:50 evertonm Exp $
 
 package fetchconfig::model::Detector; # fetchconfig/model/Detector.pm
 
@@ -27,6 +27,7 @@ use fetchconfig::model::CiscoCAT;
 use fetchconfig::model::FortiGate;
 use fetchconfig::model::ProCurve;
 use fetchconfig::model::Parks;
+use fetchconfig::model::Riverstone;
 
 my $logger;
 my %model_table;
@@ -135,6 +136,7 @@ sub init {
     $class->register(fetchconfig::model::FortiGate->new($log));
     $class->register(fetchconfig::model::ProCurve->new($log));
     $class->register(fetchconfig::model::Parks->new($log));
+    $class->register(fetchconfig::model::Riverstone->new($log));
 }
 
 1;
